==> libnet_1.1.4.orig.tar.gz: libnet-1.1.4/include/ifaddrlist.h <==
/*
 * Copyright (c) 1997
 *      The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that: (1) source code distributions
 * retain the above copyright notice and this paragraph in its entirety, (2)
 * distributions including binary code include the above copyright notice and
 * this paragraph in its entirety in the documentation or other materials
 * provided with the distribution, and (3) all advertising materials mentioning
 * features or use of this software display the following acknowledgement:
 * ``This product includes software developed by the University of California,
 * Lawrence Berkeley Laboratory and its contributors.'' Neither the name of
 * the University nor the names of its contributors may be used to endorse
 * or promote products derived from this software without specific prior
 * written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 */

struct ifaddrlist
{
#if (HAVE_SOLARIS || HAVE_HPUX11)
    u_int addr;
#else
    u_int32_t addr;              
#endif
    char *device;
};

struct libnet_ifaddr_list
{
    u_int32_t addr;
    char *device;
};

int
ifaddrlist(
    struct ifaddrlist **,
    int8_t *
    );


int
set_up_interface(
    struct sockaddr_in **,
    u_int8_t **
    );

/* EOF */

==> libnet_1.1.6+dfsg.orig.tar.gz: libnet-1.1.6/include/ifaddrlist.h <==
/*
 * Copyright (c) 1997
 *      The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that: (1) source code distributions
 * retain the above copyright notice and this paragraph in its entirety, (2)
 * distributions including binary code include the above copyright notice and
 * this paragraph in its entirety in the documentation or other materials
 * provided with the distribution, and (3) all advertising materials mentioning
 * features or use of this software display the following acknowledgement:
 * ``This product includes software developed by the University of California,
 * Lawrence Berkeley Laboratory and its contributors.'' Neither the name of
 * the University nor the names of its contributors may be used to endorse
 * or promote products derived from this software without specific prior
 * written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 */

struct ifaddrlist
{
#if (HAVE_SOLARIS || HAVE_HPUX11)
    uint addr;
#else
    uint32_t addr;              
#endif
    char *device;
};

struct libnet_ifaddr_list
{
    uint32_t addr;
    char *device;
};

int
ifaddrlist(
    struct ifaddrlist **,
    int8_t *
    );


int
set_up_interface(
    struct sockaddr_in **,
    uint8_t **
    );

/* EOF */
